@@ -198,9 +198,7 @@ class PageNumberPagination(BasePagination):
             return None
 
         paginator = self.django_paginator_class(queryset, page_size)
-        page_number = request.query_params.get(self.page_query_param, 1)
-        if page_number in self.last_page_strings:
-            page_number = paginator.num_pages
+        page_number = self.get_page_number(request, paginator)
 
         try:
             self.page = paginator.page(page_number)
@@ -217,6 +215,12 @@ class PageNumberPagination(BasePagination):
         self.request = request
         return list(self.page)
 
+    def get_page_number(self, request, paginator):
+        page_number = request.query_params.get(self.page_query_param, 1)
+        if page_number in self.last_page_strings:
+            page_number = paginator.num_pages
+        return page_number
+
     def get_paginated_response(self, data):
         return Response(OrderedDict([
             ('count', self.page.paginator.count),
@@ -376,11 +380,11 @@ class LimitOffsetPagination(BasePagination):
     template = 'rest_framework/pagination/numbers.html'
 
     def paginate_queryset(self, queryset, request, view=None):
-        self.count = self.get_count(queryset)
         self.limit = self.get_limit(request)
         if self.limit is None:
             return None
 
+        self.count = self.get_count(queryset)
         self.offset = self.get_offset(request)
         self.request = request
         if self.count > self.limit and self.template is not None:
@@ -484,8 +488,7 @@ class LimitOffsetPagination(BasePagination):
                 _divide_with_ceil(self.offset, self.limit)
             )
 
-            if final < 1:
-                final = 1
+            final = max(final, 1)
         else:
             current = 1
             final = 1
