@@ -60,8 +60,8 @@ class URLPathVersioning(BaseVersioning):
     An example URL conf for two views that accept two different versions.
 
     urlpatterns = [
-        url(r'^(?P<version>[v1|v2]+)/users/$', users_list, name='users-list'),
-        url(r'^(?P<version>[v1|v2]+)/users/(?P<pk>[0-9]+)/$', users_detail, name='users-detail')
+        re_path(r'^(?P<version>[v1|v2]+)/users/$', users_list, name='users-list'),
+        re_path(r'^(?P<version>[v1|v2]+)/users/(?P<pk>[0-9]+)/$', users_detail, name='users-detail')
     ]
 
     GET /1.0/something/ HTTP/1.1
@@ -99,14 +99,14 @@ class NamespaceVersioning(BaseVersioning):
 
     # users/urls.py
     urlpatterns = [
-        url(r'^/users/$', users_list, name='users-list'),
-        url(r'^/users/(?P<pk>[0-9]+)/$', users_detail, name='users-detail')
+        path('/users/', users_list, name='users-list'),
+        path('/users/<int:pk>/', users_detail, name='users-detail')
     ]
 
     # urls.py
     urlpatterns = [
-        url(r'^v1/', include('users.urls', namespace='v1')),
-        url(r'^v2/', include('users.urls', namespace='v2'))
+        path('v1/', include('users.urls', namespace='v1')),
+        path('v2/', include('users.urls', namespace='v2'))
     ]
 
     GET /1.0/something/ HTTP/1.1
