@@ -24,6 +24,10 @@ def pytest_configure(config):
             'default': {
                 'ENGINE': 'django.db.backends.sqlite3',
                 'NAME': ':memory:'
+            },
+            'secondary': {
+                'ENGINE': 'django.db.backends.sqlite3',
+                'NAME': ':memory:'
             }
         },
         SITE_ID=1,
@@ -67,22 +71,19 @@ def pytest_configure(config):
     )
 
     # guardian is optional
-    # Note that for the test cases we're installing a version of django-guardian
-    # that's only compatible with Django 2.0+.
-    if django.VERSION >= (2, 0, 0):
-        try:
-            import guardian  # NOQA
-        except ImportError:
-            pass
-        else:
-            settings.ANONYMOUS_USER_ID = -1
-            settings.AUTHENTICATION_BACKENDS = (
-                'django.contrib.auth.backends.ModelBackend',
-                'guardian.backends.ObjectPermissionBackend',
-            )
-            settings.INSTALLED_APPS += (
-                'guardian',
-            )
+    try:
+        import guardian  # NOQA
+    except ImportError:
+        pass
+    else:
+        settings.ANONYMOUS_USER_ID = -1
+        settings.AUTHENTICATION_BACKENDS = (
+            'django.contrib.auth.backends.ModelBackend',
+            'guardian.backends.ObjectPermissionBackend',
+        )
+        settings.INSTALLED_APPS += (
+            'guardian',
+        )
 
     if config.getoption('--no-pkgroot'):
         sys.path.pop(0)
