@@ -1,3 +1,6 @@
+import sys
+
+import pytest
 from django.test import TestCase
 
 from rest_framework.compat import apply_markdown
@@ -30,36 +33,7 @@ indented
 
 # If markdown is installed we also test it's working
 # (and that our wrapped forces '=' to h2 and '-' to h3)
-MARKED_DOWN_HILITE = """
-<div class="highlight"><pre><span></span><span \
-class="p">[{</span><br />    <span class="nt">&quot;alpha&quot;</span><span\
- class="p">:</span> <span class="mi">1</span><span class="p">,</span><br />\
-    <span class="nt">&quot;beta: &quot;</span><span class="err">this</span>\
- <span class="err">is</span> <span class="err">a</span> <span class="err">\
-string&quot;</span><br /><span class="p">}]</span><br /></pre></div>
-
-<p><br /></p>"""
-
-MARKED_DOWN_NOT_HILITE = """
-<p><code>json
-[{
-    "alpha": 1,
-    "beta: "this is a string"
-}]</code></p>"""
-
-# We support markdown < 2.1 and markdown >= 2.1
-MARKED_DOWN_lt_21 = """<h2>an example docstring</h2>
-<ul>
-<li>list</li>
-<li>list</li>
-</ul>
-<h3>another header</h3>
-<pre><code>code block
-</code></pre>
-<p>indented</p>
-<h2 id="hash_style_header">hash style header</h2>%s"""
-
-MARKED_DOWN_gte_21 = """<h2 id="an-example-docstring">an example docstring</h2>
+MARKDOWN_BASE = """<h2 id="an-example-docstring">an example docstring</h2>
 <ul>
 <li>list</li>
 <li>list</li>
@@ -70,6 +44,27 @@ MARKED_DOWN_gte_21 = """<h2 id="an-example-docstring">an example docstring</h2>
 <p>indented</p>
 <h2 id="hash-style-header">hash style header</h2>%s"""
 
+MARKDOWN_gte_33 = """
+<div class="highlight"><pre><span></span><span class="p">[{</span><br />\
+    <span class="nt">&quot;alpha&quot;</span><span class="p">:</span>\
+ <span class="mi">1</span><span class="p">,</span><br />\
+    <span class="nt">&quot;beta: &quot;</span><span class="err">this\
+</span> <span class="err">is</span> <span class="err">a</span> \
+<span class="err">string&quot;</span><br /><span class="p">}]</span>\
+<br /></pre></div>
+<p><br /></p>"""
+
+MARKDOWN_lt_33 = """
+<div class="highlight"><pre><span></span><span class="p">[{</span><br />\
+    <span class="nt">&quot;alpha&quot;</span><span class="p">:</span>\
+ <span class="mi">1</span><span class="p">,</span><br />\
+    <span class="nt">&quot;beta: &quot;</span><span class="err">this\
+</span> <span class="err">is</span> <span class="err">a</span>\
+ <span class="err">string&quot;</span><br /><span class="p">}]</span>\
+<br /></pre></div>
+
+<p><br /></p>"""
+
 
 class TestViewNamesAndDescriptions(TestCase):
     def test_view_name_uses_class_name(self):
@@ -165,23 +160,16 @@ class TestViewNamesAndDescriptions(TestCase):
 
         assert MockView().get_view_description() == 'a gettext string'
 
+    @pytest.mark.skipif(not apply_markdown, reason="Markdown is not installed")
     def test_markdown(self):
         """
         Ensure markdown to HTML works as expected.
         """
-        if apply_markdown:
-            md_applied = apply_markdown(DESCRIPTION)
-            gte_21_match = (
-                md_applied == (
-                    MARKED_DOWN_gte_21 % MARKED_DOWN_HILITE) or
-                md_applied == (
-                    MARKED_DOWN_gte_21 % MARKED_DOWN_NOT_HILITE))
-            lt_21_match = (
-                md_applied == (
-                    MARKED_DOWN_lt_21 % MARKED_DOWN_HILITE) or
-                md_applied == (
-                    MARKED_DOWN_lt_21 % MARKED_DOWN_NOT_HILITE))
-            assert gte_21_match or lt_21_match
+        # Markdown 3.3 is only supported on Python 3.6 and higher
+        if sys.version_info >= (3, 6):
+            assert apply_markdown(DESCRIPTION) == MARKDOWN_BASE % MARKDOWN_gte_33
+        else:
+            assert apply_markdown(DESCRIPTION) == MARKDOWN_BASE % MARKDOWN_lt_33
 
 
 def test_dedent_tabs():
