@@ -1,6 +1,7 @@
 import inspect
 import pickle
 import re
+import sys
 from collections import ChainMap
 from collections.abc import Mapping
 
@@ -204,6 +205,13 @@ class TestSerializer:
                 exceptions.ErrorDetail(string='Raised error', code='invalid')
             ]}
 
+    @pytest.mark.skipif(
+        sys.version_info < (3, 7),
+        reason="subscriptable classes requires Python 3.7 or higher",
+    )
+    def test_serializer_is_subscriptable(self):
+        assert serializers.Serializer is serializers.Serializer["foo"]
+
 
 class TestValidateMethod:
     def test_non_field_error_validate_method(self):
